==> beast-0.4.1-rc3.tar.gz: beast-0.4.1-rc3/beast-gtk/bstmarshal.h <==

#ifndef __bst_marshal_MARSHAL_H__
#define __bst_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* NONE:POINTER (bstmarshal.list:25) */
#define bst_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define bst_marshal_NONE__POINTER	bst_marshal_VOID__POINTER

/* NONE:POINTER,POINTER (bstmarshal.list:26) */
extern void bst_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define bst_marshal_NONE__POINTER_POINTER	bst_marshal_VOID__POINTER_POINTER

/* NONE:UINT,UINT (bstmarshal.list:27) */
extern void bst_marshal_VOID__UINT_UINT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT	bst_marshal_VOID__UINT_UINT

/* NONE:UINT,INT (bstmarshal.list:28) */
extern void bst_marshal_VOID__UINT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
#define bst_marshal_NONE__UINT_INT	bst_marshal_VOID__UINT_INT

/* NONE:UINT,UINT,UINT,UINT,UINT,UINT,UINT (bstmarshal.list:29) */
extern void bst_marshal_VOID__UINT_UINT_UINT_UINT_UINT_UINT_UINT (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
                                                                  const GValue *param_values,
                                                                  gpointer      invocation_hint,
                                                                  gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT_UINT_UINT_UINT_UINT_UINT	bst_marshal_VOID__UINT_UINT_UINT_UINT_UINT_UINT_UINT

/* NONE:UINT (bstmarshal.list:30) */
#define bst_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT
#define bst_marshal_NONE__UINT	bst_marshal_VOID__UINT

/* NONE:UINT,UINT,FLOAT (bstmarshal.list:31) */
extern void bst_marshal_VOID__UINT_UINT_FLOAT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT_FLOAT	bst_marshal_VOID__UINT_UINT_FLOAT

/* NONE:UINT,UINT,INT,BOXED (bstmarshal.list:32) */
extern void bst_marshal_VOID__UINT_UINT_INT_BOXED (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT_INT_BOXED	bst_marshal_VOID__UINT_UINT_INT_BOXED

/* NONE:UINT,UINT,BOXED (bstmarshal.list:33) */
extern void bst_marshal_VOID__UINT_UINT_BOXED (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT_BOXED	bst_marshal_VOID__UINT_UINT_BOXED

/* BOOL:BOOL (bstmarshal.list:34) */
extern void bst_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
#define bst_marshal_BOOL__BOOL	bst_marshal_BOOLEAN__BOOLEAN

/* NONE:UINT,POINTER (bstmarshal.list:35) */
#define bst_marshal_VOID__UINT_POINTER	g_cclosure_marshal_VOID__UINT_POINTER
#define bst_marshal_NONE__UINT_POINTER	bst_marshal_VOID__UINT_POINTER

/* NONE:OBJECT,OBJECT (bstmarshal.list:36) */
extern void bst_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
#define bst_marshal_NONE__OBJECT_OBJECT	bst_marshal_VOID__OBJECT_OBJECT

/* NONE:STRING (bstmarshal.list:37) */
#define bst_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
#define bst_marshal_NONE__STRING	bst_marshal_VOID__STRING

/* NONE:BOOLEAN (bstmarshal.list:38) */
#define bst_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
#define bst_marshal_NONE__BOOLEAN	bst_marshal_VOID__BOOLEAN

/* BOOLEAN:UINT (bstmarshal.list:39) */
extern void bst_marshal_BOOLEAN__UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* NONE:BOXED (bstmarshal.list:40) */
#define bst_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
#define bst_marshal_NONE__BOXED	bst_marshal_VOID__BOXED

G_END_DECLS

#endif /* __bst_marshal_MARSHAL_H__ */

==> beast-0.5.3.tar.gz: beast-0.5.3/beast-gtk/bstmarshal.h <==

#ifndef __bst_marshal_MARSHAL_H__
#define __bst_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* NONE:POINTER (./bstmarshal.list:25) */
#define bst_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define bst_marshal_NONE__POINTER	bst_marshal_VOID__POINTER

/* NONE:POINTER,POINTER (./bstmarshal.list:26) */
extern void bst_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define bst_marshal_NONE__POINTER_POINTER	bst_marshal_VOID__POINTER_POINTER

/* NONE:UINT,UINT (./bstmarshal.list:27) */
extern void bst_marshal_VOID__UINT_UINT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT	bst_marshal_VOID__UINT_UINT

/* NONE:UINT,INT (./bstmarshal.list:28) */
extern void bst_marshal_VOID__UINT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
#define bst_marshal_NONE__UINT_INT	bst_marshal_VOID__UINT_INT

/* NONE:BOOLEAN,OBJECT (./bstmarshal.list:29) */
extern void bst_marshal_VOID__BOOLEAN_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
#define bst_marshal_NONE__BOOLEAN_OBJECT	bst_marshal_VOID__BOOLEAN_OBJECT

/* NONE:INT (./bstmarshal.list:30) */
#define bst_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
#define bst_marshal_NONE__INT	bst_marshal_VOID__INT

/* NONE:UINT,UINT,UINT,UINT,UINT,UINT,UINT (./bstmarshal.list:31) */
extern void bst_marshal_VOID__UINT_UINT_UINT_UINT_UINT_UINT_UINT (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
                                                                  const GValue *param_values,
                                                                  gpointer      invocation_hint,
                                                                  gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT_UINT_UINT_UINT_UINT_UINT	bst_marshal_VOID__UINT_UINT_UINT_UINT_UINT_UINT_UINT

/* NONE:UINT (./bstmarshal.list:32) */
#define bst_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT
#define bst_marshal_NONE__UINT	bst_marshal_VOID__UINT

/* NONE:UINT,UINT,FLOAT (./bstmarshal.list:33) */
extern void bst_marshal_VOID__UINT_UINT_FLOAT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT_FLOAT	bst_marshal_VOID__UINT_UINT_FLOAT

/* NONE:UINT,UINT,INT,BOXED (./bstmarshal.list:34) */
extern void bst_marshal_VOID__UINT_UINT_INT_BOXED (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT_INT_BOXED	bst_marshal_VOID__UINT_UINT_INT_BOXED

/* NONE:UINT,UINT,BOXED (./bstmarshal.list:35) */
extern void bst_marshal_VOID__UINT_UINT_BOXED (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define bst_marshal_NONE__UINT_UINT_BOXED	bst_marshal_VOID__UINT_UINT_BOXED

/* NONE:UINT,INT,BOXED (./bstmarshal.list:36) */
extern void bst_marshal_VOID__UINT_INT_BOXED (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
#define bst_marshal_NONE__UINT_INT_BOXED	bst_marshal_VOID__UINT_INT_BOXED

/* BOOL:BOOL (./bstmarshal.list:37) */
extern void bst_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
#define bst_marshal_BOOL__BOOL	bst_marshal_BOOLEAN__BOOLEAN

/* NONE:UINT,POINTER (./bstmarshal.list:38) */
#define bst_marshal_VOID__UINT_POINTER	g_cclosure_marshal_VOID__UINT_POINTER
#define bst_marshal_NONE__UINT_POINTER	bst_marshal_VOID__UINT_POINTER

/* NONE:OBJECT,OBJECT (./bstmarshal.list:39) */
extern void bst_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
#define bst_marshal_NONE__OBJECT_OBJECT	bst_marshal_VOID__OBJECT_OBJECT

/* NONE:STRING (./bstmarshal.list:40) */
#define bst_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
#define bst_marshal_NONE__STRING	bst_marshal_VOID__STRING

/* NONE:BOOLEAN (./bstmarshal.list:41) */
#define bst_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
#define bst_marshal_NONE__BOOLEAN	bst_marshal_VOID__BOOLEAN

/* BOOLEAN:UINT (./bstmarshal.list:42) */
extern void bst_marshal_BOOLEAN__UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* NONE:BOXED (./bstmarshal.list:43) */
#define bst_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
#define bst_marshal_NONE__BOXED	bst_marshal_VOID__BOXED

G_END_DECLS

#endif /* __bst_marshal_MARSHAL_H__ */
